<?php declare(strict_types=1);

namespace Plugin\css_portlets\Portlets\CSSArtikel;


use JTL\OPC\InputType;
use JTL\OPC\Portlet;
use JTL\OPC\PortletInstance;
use JTL\Helpers\Product;
use JTL\Catalog\Product\Artikel;
use JTL\Shop;

/**
 * Class Image
 * @package JTL\OPC\Portlets
 */
class CSSArtikel extends Portlet
{
	/**
	 * @param PortletInstance $instance
	 * @return bool|string
	 */
	public function getRoundedProp(PortletInstance $instance)
	{
		return match ($instance->getProperty('shape')) {
			'rounded' => true,
			'circle'  => 'circle',
			default   => false,
		};
	}

	public function getArticleByArtNr($artNr='') {
		$db = Shop::Container()->getDB();
		$oArtikel = $db->select('tartikel','cArtNr',$artNr);

		if($oArtikel !== null) {
			$kArtikel = $oArtikel->kArtikel;
			$oArtikel = new Artikel();
			$oArtikelOptionen = new \stdClass ();
			$oArtikelOptionen->nMerkmale = 0;
			$oArtikelOptionen->nAttribute = 1;
			$oArtikelOptionen->nArtikelAttribute = 1;
			$oArtikel->fuelleArtikel ( (int) $kArtikel, $oArtikelOptionen );
		}
		return $oArtikel;
	}


	/**
	 * @param PortletInstance $instance
	 * @return bool
	 */
	public function getThumbnailProp(PortletInstance $instance): bool
	{
		return $instance->getProperty('shape') === 'thumbnail';
	}

	/**
	 * @return string
	 */
	public function getButtonHtml(): string
	{
		return $this->getFontAwesomeButtonHtml('far fa-image');
	}

	/**
	 * @return array
	 */
	public function getPropertyDesc(): array
	{
		return [
			'src'        => [
				'label'   => \__('Image'),
				'type'    => InputType::IMAGE,
				'default' => '',
			],
			'shape'      => [
				'label'      => \__('shape'),
				'type'       => InputType::SELECT,
				'options'    => [
					'normal'    => \__('shapeNormal'),
					'rounded'   => \__('shapeRoundedCorners'),
					'circle'    => \__('shapeCircle'),
					'thumbnail' => \__('shapeThumbnail'),
				],
				'width' => 25,
			],
			'align' => [
				'type'       => InputType::SELECT,
				'label'      => \__('alignment'),
				'options'    => [
					'center' => \__('centered'),
					'left'   => \__('left'),
					'right'  => \__('right'),
				],
				'default'    => 'center',
				'width'      => 25,
				'desc'       => \__('alignmentDesc')
			],
			'alt'        => [
				'label' => \__('alternativeText'),
				'width'      => 50,
			],
			'desc'        => [
				'label' => \__('Banner Text'),
				'width'      => 100,
			],
			'isArtikel' => [
				'type'     => InputType::CHECKBOX,
				'label'    => \__('isArtikel'),
				'children' => [
					'cArtNr' => [
						'type'  => InputType::TEXT,
						'label' => \__('cArtNr'),
						'width' => 50,
						'desc'  => \__('Artikeldesc')
					],
					'link-text' => [
						'label'      => \__('Link Text'),
						'width'      => 100,
					],
					'new-tab' => [
						'type'       => InputType::CHECKBOX,
						'label'      => \__('openInNewTab'),
						'width'      => 50,
						'desc'       => \__('openInNewTabDesc')
					],
				],
			],
		];
	}

	/**
	 * @return array
	 */
	public function getPropertyTabs(): array
	{
		return [
			\__('Styles') => 'styles',
		];
	}
}
