<?php declare(strict_types=1);
/**
 * 
 * @copyright (c) css-umsetzung
 * 
 */

namespace Plugin\css_portlets\Portlets\CSSSlider;

use Illuminate\Support\Collection;
use JTL\Catalog\Product\Artikel;
use JTL\Exceptions\CircularReferenceException;
use JTL\Exceptions\ServiceNotFoundException;
use JTL\Filter\AbstractFilter;
use JTL\Filter\Config;
use JTL\Filter\ProductFilter;
use JTL\Filter\Type;
use JTL\OPC\InputType;
use JTL\OPC\Portlet;
use JTL\OPC\PortletInstance;
use JTL\Shop;

/**
 * Class CSSSlider
 * @package JTL\OPC\Portlets
 */
class CSSSlider extends Portlet
{
	
	
    /**
     * @param PortletInstance $instance
     * @return bool|string
     */
    public function getRoundedProp(PortletInstance $instance)
    {
        switch ($instance->getProperty('shape')) {
            case 'rounded':
                return true;
            case 'circle':
                return 'circle';
            case 'normal':
            default:
                return false;
        }
    }

    /**
     * @param PortletInstance $instance
     * @return bool
     */
    public function getThumbnailProp(PortletInstance $instance): bool
    {
        return $instance->getProperty('shape') === 'thumbnail';
    }

    /**
     * @return string
     */
    public function getButtonHtml(): string
    {
        return $this->getFontAwesomeButtonHtml('far fa-image');
    }


		public function extraContent() {
			$smarty = Shop::Smarty();
			return $smarty->fetch($this->getBasePath() . "css.tpl");
		}

	/**
     * @return array
     */
    public function getPropertyDesc(): array
    {

        return [
	        'hint'      => [
		        'label'                => \__('note'),
		        'type'                 => InputType::HINT,
		        'class'                => '',
		        'text'                 => self::extraContent(),
	        ],

	        'slides'                      => [
		        'label'      => \__('images'),
		        'type'       => InputType::IMAGE_SET,
		        'default'    => [],
		        'useLinks'   => true,
		        'useTitles'  => true,
	        ],
	        'slider-animation-speed'      => [
		        'label'      => \__('sliderAnimationSpeed'),
		        'type'       => InputType::NUMBER,
		        'default'    => 1500,
		        'width'      => 50,
	        ],
	        'slider-animation-pause'      => [
		        'label'      => \__('pause'),
		        'type'       => InputType::NUMBER,
		        'default'    => 6000,
		        'width'      => 50,
	        ],
	        'slider-start'                => [
		        'label'      => \__('autoStart'),
		        'type'       => InputType::RADIO,
		        'options'    => [
			        'true'  => \__('yes'),
			        'false' => \__('no'),
		        ],
		        'default'    => 'true',
		        'inline'     => true,
		        'width'      => 25,
	        ],
	        'slider-pause'                => [
		        'label'      => \__('pauseOnHover'),
		        'type'       => InputType::RADIO,
		        'options'    => [
			        'true'  => \__('pauseOnHoverPause'),
			        'false' => \__('pauseOnHoverContinue'),
		        ],
		        'default'    => 'false',
		        'width'      => 25,
	        ],
	        'slider-navigation'           => [
		        'label'      => \__('pointNavigation'),
		        'type'       => InputType::RADIO,
		        'options'    => [
			        'true'  => \__('yes'),
			        'false' => \__('no'),
		        ],
		        'default'    => 'false',
		        'width'      => 25,
	        ],
	        'slider-direction-navigation' => [
		        'label'      => \__('showNavigationArrows'),
		        'type'       => InputType::RADIO,
		        'options'    => [
			        'true'  => \__('yes'),
			        'false' => \__('no'),
		        ],
		        'default'    => 'false',
		        'width'      => 25
	        ],
	        'gridHint'      => [
		        'label'                => \__('sadaa'),
		        'type'                 => InputType::HINT,
		        'class'                => 'default',
		        'text'                 => \__('<strong>Bitte geben Sie die Anzahl der sichtbaren Elemente zur jeweiligen Ansicht ein</strong>'),
	        ],
	        'xs' => [
		        'label' => \__('Mobil (XS)'),
		        'type'  => InputType::SELECT,
		        'width' => 25,
		        'default'    => '1',
		        'options'    => [
			        '1' => \__('1'),
			        '2' => \__('2'),
			        '3' => \__('3'),
			        '4' => \__('4'),
			        '5' => \__('5'),
			        '6' => \__('6'),
			        '7' => \__('7'),
			        '8' => \__('8'),
			        '9' => \__('9'),
			        '10' => \__('10'),
			        '11' => \__('11'),
			        '12' => \__('12'),
		        ],
	        ],
	        'sm' => [
		        'label' => \__('Tablet (SM)'),
		        'type'  => InputType::SELECT,
		        'width' => 25,
		        'default'    => '2',
		        'options'    => [
			        '1' => \__('1'),
			        '2' => \__('2'),
			        '3' => \__('3'),
			        '4' => \__('4'),
			        '5' => \__('5'),
			        '6' => \__('6'),
			        '7' => \__('7'),
			        '8' => \__('8'),
			        '9' => \__('9'),
			        '10' => \__('10'),
			        '11' => \__('11'),
			        '12' => \__('12'),
		        ],
	        ],
	        'md' => [
		        'label' => \__('Desktop (MD)'),
		        'type'  => InputType::SELECT,
		        'width' => 25,
		        'default'    => '3',
		        'options'    => [
			        '1' => \__('1'),
			        '2' => \__('2'),
			        '3' => \__('3'),
			        '4' => \__('4'),
			        '5' => \__('5'),
			        '6' => \__('6'),
			        '7' => \__('7'),
			        '8' => \__('8'),
			        '9' => \__('9'),
			        '10' => \__('10'),
			        '11' => \__('11'),
			        '12' => \__('12'),
		        ],
	        ],
	        'lg' => [
		        'label' => \__('Desktop (LG)'),
		        'type'  => InputType::SELECT,
		        'width' => 25,
		        'default'    => '4',
		        'options'    => [
			        '1' => \__('1'),
			        '2' => \__('2'),
			        '3' => \__('3'),
			        '4' => \__('4'),
			        '5' => \__('5'),
			        '6' => \__('6'),
			        '7' => \__('7'),
			        '8' => \__('8'),
			        '9' => \__('9'),
			        '10' => \__('10'),
			        '11' => \__('11'),
			        '12' => \__('12'),
		        ],
	        ],

        ];
    }

    /**
     * @return array
     */
    public function getPropertyTabs(): array
    {
	    return [
		    \__('Slides') => ['slides'],
		    \__('Styles') => 'styles',
	    ];
    }
    
    
    public function gibWas($cArtNr=null) {
    	$db = Shop::Container()->getDB();
    	$cache = Shop::Container()->getCache();
    	$defaultOptions = Artikel::getDefaultOptions();
    	$obj = $db->select("tartikel","cArtNr",$cArtNr);
#echo "<pre style='text-align:left; background-color:#ffffff; color:#333333;'>".__FILE__.' / '.__LINE__."<br />".print_r($obj,true)."</pre>";
#die("File: ".__FILE__."<br>\nFunction: ".__FUNCTION__."<br>\nLine: ".__LINE__."<br>\n");

    	$oProduct= (new Artikel())->fuelleArtikel((int)$obj->kArtikel, $defaultOptions);
    	return $oProduct;
    }
    
    
    
    
    /**
     * @param PortletInstance $instance
     * @return Collection
     */
    public function getFilteredProductIds(PortletInstance $instance): Collection
    {
        $enabledFilters = $instance->getProperty('filters');
        $productFilter  = new ProductFilter(
            Config::getDefault(),
            Shop::Container()->getDB(),
            Shop::Container()->getCache()
        );

        foreach ($enabledFilters as $enabledFilter) {
            /** @var AbstractFilter $newFilter * */
            $newFilter = new $enabledFilter['class']($productFilter);
            $newFilter->setType(Type::AND);
            $productFilter->addActiveFilter($newFilter, $enabledFilter['value']);
        }

        return $productFilter->getProductKeys();
    }
    

    /**
     * @param PortletInstance $instance
     * @return array
     * @throws CircularReferenceException
     * @throws ServiceNotFoundException
     */
    public function getFilteredProducts(PortletInstance $instance): array
    {
        $products       = [];
        $defaultOptions = Artikel::getDefaultOptions();
        foreach ($this->getFilteredProductIds($instance) as $productID) {
            $products[] = (new Artikel())->fuelleArtikel($productID, $defaultOptions);
        }

        return $products;
    }
    

}
